import java.util.Objects;


/**
 * Speichert einen Bruch aus zwei integern ab
 * @author p8q-yhw-u1
 *
 */
public class Bruch {

    private int zaehler;
    private int nenner;
    
    /**
     * Erzeugt ein Bruch Objekt mit Zähler und Nenner
     * @param zaehler
     * @param nenner
     */
    public Bruch(int zaehler, int nenner) {
        this.setZaehler(zaehler);
        this.setNenner(nenner);
    }
    
    /**
     * Setzt den Zähler des Bruchs
     * @param zaehler
     */
    public void setZaehler(int zaehler) {
        this.zaehler = zaehler;
    }
    
    /**
     * Setzt den Nenner des Bruchs
     * @param nenner darf nicht 0 sein
     */
    public void setNenner(int nenner) {
        if (nenner == 0) {
            throw new IllegalArgumentException("Nenner darf nicht 0 sein");
        }
        this.nenner = nenner;
    }
    
    /**
     * Liefert den Zähler des Bruchs
     * @return Zähler
     */
    public int getZaehler() {
        return this.zaehler;
    }
    
    /**
     * Liefert den Nenner des Bruchs
     * @return Nenner
     */
    public int getNenner() {
        return this.nenner;
    }
    
    /**
     * Liefert den Bruch als Dezimalzahl
     * @return
     */
    public double zahl() {
        return (double) this.zaehler / this.nenner;
    }
    
    /**
     * Vergleicht Bruch auf Gleichheit mit einem anderen Objekt beliebiger Art
     * Liefert false wenn das Objekt nicht vom Typ Bruch ist
     */
    @Override
    public boolean equals(Object b) {
        return b instanceof Bruch ? this.equals((Bruch) b) : false;
    }
    
    /**
     * Überprüft Bruch mit einem anderen Bruch auf Gleichheit
     * @param b der zu vergleichende Bruch
     * @return true falls die beiden Brüche die gleiche Zahl ausdrücken
     */
    public boolean equals(Bruch b) {
        return this.zaehler * b.nenner == this.nenner * b.zaehler;
        /*
         * Alternative Implementierung wäre
         *   return this.hashCode() == b.hashCode();
         *  allerdings deutlich ineffizienter
         */
    }
    
    /**
     * Findet mittels des Euklidischen Algorithmus den größten
     * gemeinsamen Teiler des Zählers und des Nenners des Bruchs
     * @return Größter gemeinsamer Teieler
     */
    public int getGgT() {
        int z = Math.abs(this.zaehler);
        int n = Math.abs(this.nenner);
        
        if (z == 0) {
            return 0;
        }
        
        while (n != 0) {
            if (z > n) {
                z -= n;
            } else {
                n -= z;
            }
        }
        return z;
    }
    
    /**
     * Liefert den Bruch in gehashter Form
     */
    @Override
    public int hashCode() {
        int ggt = this.getGgT();
        int sign = 1;
        
        /*
         * Vorzeichen bestimmen 
         */
        if (this.zaehler < 0) sign *= -1;
        if (this.nenner < 0) sign *= -1;
        
        /*
         * Hash des Bruchs berechnen.
         * Wenn negativ wird immer der Zähler als negativ angegeben, nie der Nenner.
         * Sorgt dafür dass -1/2 == 1/-2
         */
        return Objects.hash(Math.abs(this.zaehler) / ggt * sign, Math.abs(this.nenner) / ggt);
    }
    
    
}
