
/**
 * Abstrakte Medium Klasse für Bücher, CDs und Zeitschriften
 * @author p8q-yhw-u1
 * Note: this class has a natural ordering that is inconsistent with equals
 */
public abstract class Medium implements Comparable<Medium> {
    private String titel;
    private int erscheinungsjahr;
    
    /**
     * Constructor eines Mediums
     * @param titel darf nicht leer sein
     * @param erscheinungsjahr darf nicht < 0 sein
     */
    public Medium(String titel, int erscheinungsjahr) {
        this.setTitel(titel);
        this.setErscheinungsjahr(erscheinungsjahr);
    }
    
    /**
     * Setzt das Erscheinungsjahr eines Mediums
     * @param erscheinungsjahr darf nicht < 0 sein
     */
    public void setErscheinungsjahr(int erscheinungsjahr) {
        if (erscheinungsjahr < 0) {
            throw new IllegalArgumentException("Erscheinungsjahr muss positiv sein");
        }
        
        this.erscheinungsjahr = erscheinungsjahr;
    }
    
    /**
     * Gibt das Erscheinungsjahr des Mediums zurücck
     * @return
     */
    public int getErscheinungsjahr() {
        return this.erscheinungsjahr;
    }
    
    /**
     * Setzt den Titel des Mediums
     * @param titel darf nicht leer sein
     */
    public void setTitel(String titel) {
        if (titel == null || titel.length() == 0) {
            throw new IllegalArgumentException("Titel darf nicht leer sein");
        }
        
        this.titel = titel;
    }
    
    /**
     * Gibt den Titel des Mediums zurück
     * @return
     */
    public String getTitel() {
        return this.titel;
    }
    
    /**
     * Gibt die Leihfrist des Mediums zurück
     * @return
     */
    public abstract int getLeihFrist();
    
    /**
     * Vergleicht das Objekt mit einem anderen Medium nach deren Erscheinungsjahren
     * 
     */
    @Override
    public int compareTo(Medium m) {
        return this.getErscheinungsjahr() - m.getErscheinungsjahr();
    }
}
