
/**
 * Klasse für Bücher mit Verlag und Autor
 * @author p8q-yhw-u1
 *
 */
public class Buch extends Medium {
    
    private String verlag;
    private String autor;
    
    /**
     * Erzeugt Buch Objekt
     * @param titel darf nicht leer sein
     * @param erscheinungsjahr darf nicht < 0 sein
     * @param verlag darf nicht leer sein
     * @param autor darf nicht leer sein
     */
    public Buch(String titel, int erscheinungsjahr, String verlag, String autor) {
        super(titel, erscheinungsjahr);
        this.setVerlag(verlag);
        this.setAutor(autor);
    }
    
    /**
     * Setzt den Verlag des Buchs
     * @param verlag darf nicht leer sein
     */
    public void setVerlag(String verlag) {
        if (verlag == null || verlag.length() == 0) {
            throw new IllegalArgumentException("Verlag darf nicht leer sein");
        }
        
        this.verlag = verlag;
    }
    
    /**
     * Gibt den Verlag des Buches zurück
     * @return
     */
    public String getVerlag() {
        return this.verlag;
    }
    
    /**
     * Setzt den Autor des Buches
     * @param autor darf nicht leer sein
     */
    public void setAutor(String autor) {
        if (autor == null || autor.length() == 0) {
            throw new IllegalArgumentException("Autor darf nicht leer sein");
        }
        
        this.autor = autor;
    }
    
    
    /**
     * Gibt den autor des Buches zurück
     * @return
     */
    public String getAutor() {
        return this.autor;
    }
    
    /**
     * Gibt die Leihfrist für Bücher zurück
     * @return
     */
    @Override
    public int getLeihFrist() {
        return 28;
    }
    
    /**
     * Gibt eine String repräsentation des Buches zurück
     */
    @Override
    public String toString() {
        return String.format(
                "%s: %s (%d) %s",
                this.getAutor(),
                this.getTitel(),
                this.getErscheinungsjahr(),
                this.getVerlag()
                );
    }
}
