
/**
 * Klasse für CDs mit Künstler und Spielzeit
 * @author p8q-yhw-u1
 *
 */
public class CD extends Medium {
    private String kuenstler;
    private int spielzeit;
    
    /**
     * Erstellt ein CD Objekt
     * @param titel darf nicht leer sein
     * @param erscheinungsjahr darf nicht < 0 sein
     * @param kuenstler darf nicht leer sein
     * @param spielzeit darf nicht < 1 sein
     */
    public CD(String titel, int erscheinungsjahr, String kuenstler, int spielzeit) {
        super(titel, erscheinungsjahr);
        this.setKuenstler(kuenstler);
        this.setGesamtspielzeit(spielzeit);
    }
    
    /**
     * Setzt den Künstler der CD
     * @param kuenstler darf nicht leer sein
     */
    public void setKuenstler(String kuenstler) {
        if (kuenstler == null || kuenstler.length() == 0) {
            throw new IllegalArgumentException("Künstler darf nicht leer sein");
        }
        this.kuenstler = kuenstler;
    }
    
    /**
     * gibt den Künstler der CD zurück
     * @return
     */
    public String getKuenstler() {
        return this.kuenstler;
    }
    
    /**
     * Setzt die Gesamtspielzeit der CD
     * @param spielzeit darf nicht < 1 sein
     */
    public void setGesamtspielzeit(int spielzeit) {
        if (spielzeit < 1) {
            throw new IllegalArgumentException("Spielzeit darf nicht kleiner als 1 sein");
        }
        
        this.spielzeit = spielzeit;
    }
    
    /**
     * Gibt die Gesamtspielzeit der CD zurück
     * @return
     */
    public int getGesamtspielzeit() {
        return this.spielzeit;
    }
    
    /**
     * Gibt die Leihfrist für CDs zurück
     * @return
     */
    @Override
    public int getLeihFrist() {
        return 14;
    }
    
    /**
     * Gibt eine String repräsentation der CD zurück
     */
    @Override
    public String toString() {
        return String.format(
                "%s: %s (%d) %d Minuten",
                this.getKuenstler(),
                this.getTitel(),
                this.getErscheinungsjahr(),
                this.getGesamtspielzeit()
                );
    }
}
