
/**
 * Klasse für Zeitschriften mit Nummer
 * @author p8q-yhw-u1
 *
 */
public class Zeitschrift extends Medium {
    private int nummer;
    
    /**
     * Erstellt ein Zeitschrift Objekt
     * @param titel darf nicht leer sein
     * @param erscheinungsjahr darf nicht < 0 sein
     * @param nummer darf nicht < 1 sein
     */
    public Zeitschrift(String titel, int erscheinungsjahr, int nummer) {
        super(titel, erscheinungsjahr);
        this.setNummer(nummer);
    }
    
    /**
     * Setzt die Nummer der Zeitschrift
     * @param nummer darf nicht < 1 sein
     */
    public void setNummer(int nummer) {
        if (nummer < 1) {
            throw new IllegalArgumentException("Nummer darf nicht kleiner als 1 sein");
        }
        
        this.nummer = nummer;
    }
    
    /**
     * Gibt die Nummer der Zeitschrift zurück
     * @return
     */
    public int getNummer() {
        return this.nummer;
    }
    
    /**
     * Gibt die Leihfrist für Zeitschriften zurück
     * @return
     */
    @Override
    public int getLeihFrist() {
        return 7;
    }
    
    /**
     * Gibt eine String repräsentation des Buches zurück
     */
    @Override
    public String toString() {
        return String.format(
                "%s (%d/%d)",
                this.getTitel(),
                this.getNummer(),
                this.getErscheinungsjahr()
                );
    }
}
